==> aseprite_1.0.5+ds.orig.tar.gz: aseprite_1.0.5/src/ui/ui.h <==
// Aseprite UI Library
// Copyright (C) 2001-2013  David Capello
//
// This file is released under the terms of the MIT license.
// Read LICENSE.txt for more information.

#ifndef UI_UI_H_INCLUDED
#define UI_UI_H_INCLUDED
#pragma once

#include "ui/accelerator.h"
#include "ui/alert.h"
#include "ui/base.h"
#include "ui/box.h"
#include "ui/button.h"
#include "ui/clipboard.h"
#include "ui/combobox.h"
#include "ui/component.h"
#include "ui/cursor.h"
#include "ui/cursor_type.h"
#include "ui/custom_label.h"
#include "ui/draw.h"
#include "ui/entry.h"
#include "ui/event.h"
#include "ui/graphics.h"
#include "ui/grid.h"
#include "ui/hit_test_event.h"
#include "ui/image_view.h"
#include "ui/init_theme_event.h"
#include "ui/keys.h"
#include "ui/label.h"
#include "ui/layout_io.h"
#include "ui/link_label.h"
#include "ui/listbox.h"
#include "ui/listitem.h"
#include "ui/load_layout_event.h"
#include "ui/manager.h"
#include "ui/menu.h"
#include "ui/message.h"
#include "ui/message_loop.h"
#include "ui/message_type.h"
#include "ui/mouse_buttons.h"
#include "ui/overlay.h"
#include "ui/overlay_manager.h"
#include "ui/paint_event.h"
#include "ui/panel.h"
#include "ui/popup_window.h"
#include "ui/preferred_size_event.h"
#include "ui/property.h"
#include "ui/register_message.h"
#include "ui/resize_event.h"
#include "ui/save_layout_event.h"
#include "ui/scroll_bar.h"
#include "ui/separator.h"
#include "ui/slider.h"
#include "ui/splitter.h"
#include "ui/system.h"
#include "ui/textbox.h"
#include "ui/theme.h"
#include "ui/timer.h"
#include "ui/tooltips.h"
#include "ui/view.h"
#include "ui/viewport.h"
#include "ui/widget.h"
#include "ui/widget_type.h"
#include "ui/widgets_list.h"
#include "ui/window.h"

#endif

==> aseprite_1.1.6+ds.orig.tar.gz: aseprite_1.1.6/src/ui/ui.h <==
// Aseprite UI Library
// Copyright (C) 2001-2016  David Capello
//
// This file is released under the terms of the MIT license.
// Read LICENSE.txt for more information.

#ifndef UI_UI_H_INCLUDED
#define UI_UI_H_INCLUDED
#pragma once

#include "ui/accelerator.h"
#include "ui/alert.h"
#include "ui/base.h"
#include "ui/box.h"
#include "ui/button.h"
#include "ui/combobox.h"
#include "ui/component.h"
#include "ui/cursor.h"
#include "ui/cursor_type.h"
#include "ui/custom_label.h"
#include "ui/entry.h"
#include "ui/event.h"
#include "ui/graphics.h"
#include "ui/grid.h"
#include "ui/hit_test_event.h"
#include "ui/image_view.h"
#include "ui/init_theme_event.h"
#include "ui/keys.h"
#include "ui/label.h"
#include "ui/layout_io.h"
#include "ui/link_label.h"
#include "ui/listbox.h"
#include "ui/listitem.h"
#include "ui/load_layout_event.h"
#include "ui/manager.h"
#include "ui/menu.h"
#include "ui/message.h"
#include "ui/message_loop.h"
#include "ui/message_type.h"
#include "ui/mouse_buttons.h"
#include "ui/overlay.h"
#include "ui/overlay_manager.h"
#include "ui/paint_event.h"
#include "ui/panel.h"
#include "ui/pointer_type.h"
#include "ui/popup_window.h"
#include "ui/property.h"
#include "ui/register_message.h"
#include "ui/resize_event.h"
#include "ui/save_layout_event.h"
#include "ui/scroll_bar.h"
#include "ui/separator.h"
#include "ui/size_hint_event.h"
#include "ui/slider.h"
#include "ui/splitter.h"
#include "ui/system.h"
#include "ui/textbox.h"
#include "ui/theme.h"
#include "ui/timer.h"
#include "ui/tooltips.h"
#include "ui/view.h"
#include "ui/viewport.h"
#include "ui/widget.h"
#include "ui/widget_type.h"
#include "ui/widgets_list.h"
#include "ui/window.h"

#endif
